@@ -1,13 +1,15 @@
 from ayugespidertools.scraper.pipelines.mongo.fantasy import AyuFtyMongoPipeline
 from ayugespidertools.scraper.pipelines.mongo.twisted import AyuTwistedMongoPipeline
+from ayugespidertools.scraper.pipelines.mysql.asynced import AsyncMysqlPipeline
 from ayugespidertools.scraper.pipelines.mysql.fantasy import AyuFtyMysqlPipeline
 from ayugespidertools.scraper.pipelines.mysql.turbo import AyuTurboMysqlPipeline
 from ayugespidertools.scraper.pipelines.mysql.twisted import AyuTwistedMysqlPipeline
 
 __all__ = [
     "AyuFtyMysqlPipeline",
-    "AyuFtyMongoPipeline",
-    "AyuTwistedMysqlPipeline",
     "AyuTurboMysqlPipeline",
+    "AyuTwistedMysqlPipeline",
+    "AsyncMysqlPipeline",
+    "AyuFtyMongoPipeline",
     "AyuTwistedMongoPipeline",
 ]
